// GMSH Geometry File
// Project: BOX
// Author: Dai Weifeng
// e-Mail: daiweifengfudan@gmail.com
// Organization: Fudan University
// Date(YYYY/MM/DD): 2011/05/31
// Version: 0.10

// Comment: A simple test for transient thermal equation
//
//


// Header Files
// Example: Include "xxxx.gm"


// Unit Definition //
// Example: mm = 1e-3;

mm = 1e-3 ;


// Constant Definition //
// Example: CL = 0.1 * mm;
BOX_L = 1.0 * mm ;
BOX_W = 2.0 * mm ;
BOX_H = 5.0 * mm ;

BOX_CL = 0.2 * mm ;
BOX_N = 4 ;

// Geometry Definition
// Variable Definition Example: [MODULE_NAME]_[POSITION]_[TYPE]_[Number] = ...

Box_Bottom_Point[] = { } ;
For i In { 0:BOX_N-1 }
	P = newp;
	Point(P) = { BOX_L/2, BOX_W/2, 0, BOX_CL } ;
	Rotate { {0,0,1}, {0,0,0}, 2*Pi*i/4 } { Point{P} ; }
	Box_Bottom_Point[] += P ;
EndFor

Box_Bottom_Line[] = { } ;
For i In { 0:BOX_N-1 }
	L = newl;
	Line(L) = { Box_Bottom_Point[i], Box_Bottom_Point[ (i+1)%BOX_N ] } ;
	Box_Bottom_Line[] += L ;
EndFor

Box_Bottom_LL = newll ;
Line Loop(Box_Bottom_LL) = Box_Bottom_Line[] ;

Box_Bottom_Surface = news ;
Ruled Surface(Box_Bottom_Surface) = { Box_Bottom_LL } ;

Box_Volume_Extrusion_Result[] = Extrude { 0, 0, BOX_H } {
	Surface{ Box_Bottom_Surface } ;
} ;

Box_Top_Surface = Box_Volume_Extrusion_Result[ 0 ] ;

Box_Volume = Box_Volume_Extrusion_Result[ 1 ] ;

Box_Side_Surface[] = Box_Volume_Extrusion_Result[ { 2:BOX_N+1 } ] ;

// Physical Geometry Definition

Physical Volume(1001) = { Box_Volume } ;

Physical Surface(1002) = {Box_Bottom_Surface } ;
Physical Surface(1003) = {Box_Top_Surface } ;

Physical Surface(1004) = Box_Side_Surface[] ;


// End


